2009-01-03 07:50:24

by Nick Andrew

[permalink] [raw]
Subject: [TRIVIAL PATCH 00/11] Fix misspelling of "firmware"

Fix misspellings of "firmware" which I noticed in 2.6.28. All are comment
changes except for the change to drivers/scsi/qla4xxx/ql4_mbx.c which
is in a string argument to dev_info().

Nick.
---

Nick Andrew (11):
Fix misspelling of "firmware" in docs for ncr53c8xx/sym53c8xx
Fix misspelling of "firmware" in powerpc Makefile
Fix misspelling of "firmware" in usb.c
Fix misspelling of "firmware" in qla1280.c
Fix misspelling of "firmware" in a100u2w.c
Fix misspelling of "firmware" in megaraid.c
Fix misspelling of "firmware" in ql4_mbx.c
Fix misspelling of "firmware" in acpi_memhotplug.c
Fix misspelling of "firmware" in ipw2100.c
Fix misspelling of "firmware" in atmel.c
Fix misspelled firmware in Kconfig


Documentation/scsi/ChangeLog.ncr53c8xx | 2 +-
Documentation/scsi/ChangeLog.sym53c8xx | 2 +-
arch/powerpc/boot/Makefile | 2 +-
drivers/acpi/acpi_memhotplug.c | 2 +-
drivers/base/Kconfig | 2 +-
drivers/net/wireless/atmel.c | 2 +-
drivers/net/wireless/ipw2100.c | 2 +-
drivers/scsi/a100u2w.c | 2 +-
drivers/scsi/megaraid.c | 4 ++--
drivers/scsi/qla1280.c | 4 ++--
drivers/scsi/qla4xxx/ql4_mbx.c | 2 +-
drivers/uwb/i1480/dfu/usb.c | 2 +-
12 files changed, 14 insertions(+), 14 deletions(-)

--
PGP Key ID = 0x418487E7 http://www.nick-andrew.net/
PGP Key fingerprint = B3ED 6894 8E49 1770 C24A 67E3 6266 6EB9 4184 87E7


2009-01-03 07:51:19

by Nick Andrew

[permalink] [raw]
Subject: [TRIVIAL PATCH 01/11] Fix misspelled firmware in Kconfig

Fix misspelled firmware in Kconfig

It's spelled "firmware".

Signed-off-by: Nick Andrew <[email protected]>
---

drivers/base/Kconfig | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)


diff --git a/drivers/base/Kconfig b/drivers/base/Kconfig
index d8e8c49..8f006f9 100644
--- a/drivers/base/Kconfig
+++ b/drivers/base/Kconfig
@@ -54,7 +54,7 @@ config FIRMWARE_IN_KERNEL
such firmware, and do not wish to use an initrd.

This single option controls the inclusion of firmware for
- every driver which uses request_firmare() and ships its
+ every driver which uses request_firmware() and ships its
firmware in the kernel source tree, to avoid a proliferation
of 'Include firmware for xxx device' options.

2009-01-03 07:52:23

by Nick Andrew

[permalink] [raw]
Subject: [TRIVIAL PATCH 02/11] Fix misspelling of "firmware" in atmel.c

Fix misspelling of "firmware" in atmel.c

It's spelled "firmware".

Signed-off-by: Nick Andrew <[email protected]>
---

drivers/net/wireless/atmel.c | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)


diff --git a/drivers/net/wireless/atmel.c b/drivers/net/wireless/atmel.c
index ecb02bd..d9058b8 100644
--- a/drivers/net/wireless/atmel.c
+++ b/drivers/net/wireless/atmel.c
@@ -3839,7 +3839,7 @@ static int reset_atmel_card(struct net_device *dev)
This routine is also responsible for initialising some
hardware-specific fields in the atmel_private structure,
including a copy of the firmware's hostinfo stucture
- which is the route into the rest of the firmare datastructures. */
+ which is the route into the rest of the firmware datastructures. */

struct atmel_private *priv = netdev_priv(dev);
u8 configuration;

2009-01-03 07:53:21

by Nick Andrew

[permalink] [raw]
Subject: [TRIVIAL PATCH 03/11] Fix misspelling of "firmware" in ipw2100.c

Fix misspelling of "firmware" in ipw2100.c

It's spelled "firmware".

Signed-off-by: Nick Andrew <[email protected]>
---

drivers/net/wireless/ipw2100.c | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)


diff --git a/drivers/net/wireless/ipw2100.c b/drivers/net/wireless/ipw2100.c
index bca7481..d617c16 100644
--- a/drivers/net/wireless/ipw2100.c
+++ b/drivers/net/wireless/ipw2100.c
@@ -1828,7 +1828,7 @@ static void ipw2100_down(struct ipw2100_priv *priv)
cancel_delayed_work(&priv->rf_kill);
}

- /* Kill the firmare hang check timer */
+ /* Kill the firmware hang check timer */
if (!priv->stop_hang_check) {
priv->stop_hang_check = 1;
cancel_delayed_work(&priv->hang_check);

2009-01-03 07:54:20

by Nick Andrew

[permalink] [raw]
Subject: [TRIVIAL PATCH 04/11] Fix misspelling of "firmware" in acpi_memhotplug.c

Fix misspelling of "firmware" in acpi_memhotplug.c

It's spelled "firmware".

Signed-off-by: Nick Andrew <[email protected]>
---

drivers/acpi/acpi_memhotplug.c | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)


diff --git a/drivers/acpi/acpi_memhotplug.c b/drivers/acpi/acpi_memhotplug.c
index 63a17b5..7a0f4aa 100644
--- a/drivers/acpi/acpi_memhotplug.c
+++ b/drivers/acpi/acpi_memhotplug.c
@@ -20,7 +20,7 @@
*
*
* ACPI based HotPlug driver that supports Memory Hotplug
- * This driver fields notifications from firmare for memory add
+ * This driver fields notifications from firmware for memory add
* and remove operations and alerts the VM of the affected memory
* ranges.
*/

2009-01-03 07:55:25

by Nick Andrew

[permalink] [raw]
Subject: [TRIVIAL PATCH 05/11] Fix misspelling of "firmware" in ql4_mbx.c

Fix misspelling of "firmware" in ql4_mbx.c

It's spelled "firmware".

Signed-off-by: Nick Andrew <[email protected]>
---

drivers/scsi/qla4xxx/ql4_mbx.c | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)


diff --git a/drivers/scsi/qla4xxx/ql4_mbx.c b/drivers/scsi/qla4xxx/ql4_mbx.c
index c577d79..051b0f5 100644
--- a/drivers/scsi/qla4xxx/ql4_mbx.c
+++ b/drivers/scsi/qla4xxx/ql4_mbx.c
@@ -392,7 +392,7 @@ int qla4xxx_get_firmware_status(struct scsi_qla_host * ha)
ha->iocb_hiwat -= IOCB_HIWAT_CUSHION;
else
dev_info(&ha->pdev->dev, "WARNING!!! You have less than %d "
- "firmare IOCBs available (%d).\n",
+ "firmware IOCBs available (%d).\n",
IOCB_HIWAT_CUSHION, ha->iocb_hiwat);

return QLA_SUCCESS;

2009-01-03 07:56:21

by Nick Andrew

[permalink] [raw]
Subject: [TRIVIAL PATCH 06/11] Fix misspelling of "firmware" in megaraid.c

Fix misspelling of "firmware" in megaraid.c

Fixed "firmware", "ownership" and grammar in the same comment.

Signed-off-by: Nick Andrew <[email protected]>
---

drivers/scsi/megaraid.c | 4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)


diff --git a/drivers/scsi/megaraid.c b/drivers/scsi/megaraid.c
index 7dc62de..9fdcd60 100644
--- a/drivers/scsi/megaraid.c
+++ b/drivers/scsi/megaraid.c
@@ -1967,8 +1967,8 @@ megaraid_abort_and_reset(adapter_t *adapter, Scsi_Cmnd *cmd, int aor)
scb->state |= aor;

/*
- * Check if this command has firmare owenership. If
- * yes, we cannot reset this command. Whenever, f/w
+ * Check if this command has firmware ownership. If
+ * yes, we cannot reset this command. Whenever f/w
* completes this command, we will return appropriate
* status from ISR.
*/

2009-01-03 07:57:19

by Nick Andrew

[permalink] [raw]
Subject: [TRIVIAL PATCH 07/11] Fix misspelling of "firmware" in a100u2w.c

Fix misspelling of "firmware" in a100u2w.c

It's spelled "firmware".

Signed-off-by: Nick Andrew <[email protected]>
---

drivers/scsi/a100u2w.c | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)


diff --git a/drivers/scsi/a100u2w.c b/drivers/scsi/a100u2w.c
index 84bb616..07df412 100644
--- a/drivers/scsi/a100u2w.c
+++ b/drivers/scsi/a100u2w.c
@@ -633,7 +633,7 @@ static int orc_device_reset(struct orc_host * host, struct scsi_cmnd *cmd, unsig
return FAILED;
}

- /* Reset device is handled by the firmare, we fill in an SCB and
+ /* Reset device is handled by the firmware, we fill in an SCB and
fire it at the controller, it does the rest */
scb->opcode = ORC_BUSDEVRST;
scb->target = target;

2009-01-03 07:58:19

by Nick Andrew

[permalink] [raw]
Subject: [TRIVIAL PATCH 08/11] Fix misspelling of "firmware" in qla1280.c

Fix misspelling of "firmware" in qla1280.c

It's spelled "firmware".

Signed-off-by: Nick Andrew <[email protected]>
---

drivers/scsi/qla1280.c | 4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)


diff --git a/drivers/uwb/i1480/dfu/usb.c b/drivers/uwb/i1480/dfu/usb.c
index 98eeeff..56d2353 100644
--- a/drivers/uwb/i1480/dfu/usb.c
+++ b/drivers/uwb/i1480/dfu/usb.c
@@ -414,7 +414,7 @@ int i1480_usb_probe(struct usb_interface *iface, const struct usb_device_id *id)
goto error_create;
}

- /* setup the fops and upload the firmare */
+ /* setup the fops and upload the firmware */
i1480->pre_fw_name = "i1480-pre-phy-0.0.bin";
i1480->mac_fw_name = "i1480-usb-0.0.bin";
i1480->mac_fw_name_deprecate = "ptc-0.0.bin";

2009-01-03 08:00:26

by Nick Andrew

[permalink] [raw]
Subject: [TRIVIAL PATCH 10/11] Fix misspelling of "firmware" in powerpc Makefile

Fix misspelling of "firmware" in powerpc Makefile

It's spelled "firmware".

Signed-off-by: Nick Andrew <[email protected]>
---

arch/powerpc/boot/Makefile | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)


diff --git a/arch/powerpc/boot/Makefile b/arch/powerpc/boot/Makefile
index 3d3daa6..42b5a2d 100644
--- a/arch/powerpc/boot/Makefile
+++ b/arch/powerpc/boot/Makefile
@@ -207,7 +207,7 @@ image-$(CONFIG_DEFAULT_UIMAGE) += uImage
#
# Theses are default targets to build images which embed device tree blobs.
# They are only required on boards which do not have FDT support in firmware.
-# Boards with newish u-boot firmare can use the uImage target above
+# Boards with newish u-boot firmware can use the uImage target above
#

# Board ports in arch/powerpc/platform/40x/Kconfig

2009-01-03 08:01:20

by Nick Andrew

[permalink] [raw]
Subject: [TRIVIAL PATCH 11/11] Fix misspelling of "firmware" in docs for ncr53c8xx/sym53c8xx

Fix misspelling of "firmware" in docs for ncr53c8xx/sym53c8xx

It's spelled "firmware".

Signed-off-by: Nick Andrew <[email protected]>
---

Documentation/scsi/ChangeLog.ncr53c8xx | 2 +-
Documentation/scsi/ChangeLog.sym53c8xx | 2 +-
2 files changed, 2 insertions(+), 2 deletions(-)


diff --git a/Documentation/scsi/ChangeLog.ncr53c8xx b/Documentation/scsi/ChangeLog.ncr53c8xx
index a9f721a..8b278c1 100644
--- a/Documentation/scsi/ChangeLog.ncr53c8xx
+++ b/Documentation/scsi/ChangeLog.ncr53c8xx
@@ -19,7 +19,7 @@ Sun Sep 24 21:30 2000 Gerard Roudier ([email protected])

Wed Jul 26 23:30 2000 Gerard Roudier ([email protected])
* version ncr53c8xx-3.4.1
- - Provide OpenFirmare path through the proc FS on PPC.
+ - Provide OpenFirmware path through the proc FS on PPC.
- Remove trailing argument #2 from a couple of #undefs.

Sun Jul 09 16:30 2000 Gerard Roudier ([email protected])
diff --git a/Documentation/scsi/ChangeLog.sym53c8xx b/Documentation/scsi/ChangeLog.sym53c8xx
index ef985ec..02ffbc1 100644
--- a/Documentation/scsi/ChangeLog.sym53c8xx
+++ b/Documentation/scsi/ChangeLog.sym53c8xx
@@ -81,7 +81,7 @@ Sun Sep 24 21:30 2000 Gerard Roudier ([email protected])

Wed Jul 26 23:30 2000 Gerard Roudier ([email protected])
* version sym53c8xx-1.7.1
- - Provide OpenFirmare path through the proc FS on PPC.
+ - Provide OpenFirmware path through the proc FS on PPC.
- Download of on-chip SRAM using memcpy_toio() doesn't work
on PPC. Restore previous method (MEMORY MOVE from SCRIPTS).
- Remove trailing argument #2 from a couple of #undefs.

2009-01-03 23:24:16

by Jiri Kosina

[permalink] [raw]
Subject: Re: [TRIVIAL PATCH 00/11] Fix misspelling of "firmware"

On Sat, 3 Jan 2009, Nick Andrew wrote:

> Fix misspellings of "firmware" which I noticed in 2.6.28. All are
> comment changes except for the change to drivers/scsi/qla4xxx/ql4_mbx.c
> which is in a string argument to dev_info().
>
> Nick.
> ---
>
> Nick Andrew (11):
> Fix misspelling of "firmware" in docs for ncr53c8xx/sym53c8xx
> Fix misspelling of "firmware" in powerpc Makefile
> Fix misspelling of "firmware" in usb.c
> Fix misspelling of "firmware" in qla1280.c
> Fix misspelling of "firmware" in a100u2w.c
> Fix misspelling of "firmware" in megaraid.c
> Fix misspelling of "firmware" in ql4_mbx.c
> Fix misspelling of "firmware" in acpi_memhotplug.c
> Fix misspelling of "firmware" in ipw2100.c
> Fix misspelling of "firmware" in atmel.c
> Fix misspelled firmware in Kconfig
>
>
> Documentation/scsi/ChangeLog.ncr53c8xx | 2 +-
> Documentation/scsi/ChangeLog.sym53c8xx | 2 +-
> arch/powerpc/boot/Makefile | 2 +-
> drivers/acpi/acpi_memhotplug.c | 2 +-
> drivers/base/Kconfig | 2 +-
> drivers/net/wireless/atmel.c | 2 +-
> drivers/net/wireless/ipw2100.c | 2 +-
> drivers/scsi/a100u2w.c | 2 +-
> drivers/scsi/megaraid.c | 4 ++--
> drivers/scsi/qla1280.c | 4 ++--
> drivers/scsi/qla4xxx/ql4_mbx.c | 2 +-
> drivers/uwb/i1480/dfu/usb.c | 2 +-
> 12 files changed, 14 insertions(+), 14 deletions(-)

Thanks Nick, I have queued the patches in the trivial tree.

diff --git a/drivers/scsi/qla1280.c b/drivers/scsi/qla1280.c
index b6cd12b..cc57a23 100644
--- a/drivers/scsi/qla1280.c
+++ b/drivers/scsi/qla1280.c
@@ -128,7 +128,7 @@
- Integrate ql12160_set_target_parameters() with 1280 version
- Make qla1280_setup() non static
- Do not call qla1280_check_for_dead_scsi_bus() on every I/O request
- sent to the card - this command pauses the firmare!!!
+ sent to the card - this command pauses the firmware!!!
Rev 3.23.15 Beta March 19, 2002, Jes Sorensen
- Clean up qla1280.h - remove obsolete QL_DEBUG_LEVEL_x definitions
- Remove a pile of pointless and confusing (srb_t **) and
@@ -659,7 +659,7 @@ static int qla1280_read_nvram(struct scsi_qla_host *ha)
/* The firmware interface is, um, interesting, in that the
* actual firmware image on the chip is little endian, thus,
* the process of taking that image to the CPU would end up
* little endian. However, the firmare interface requires it
* to be read a word (two bytes) at a time.
*
* The net result of this would be that the word (and

2009-01-03 07:59:19

by Nick Andrew

[permalink] [raw]
Subject: [TRIVIAL PATCH 09/11] Fix misspelling of "firmware" in usb.c

Fix misspelling of "firmware" in usb.c

It's spelled "firmware".

Signed-off-by: Nick Andrew <[email protected]>
---

drivers/uwb/i1480/dfu/usb.c | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)
@@ -659,7 +659,7 @@ static int qla1280_read_nvram(struct scsi_qla_host *ha)
* actual firmware image on the chip is little endian, thus,
* the process of taking that image to the CPU would end up
- * little endian. However, the firmare interface requires it
+ * little endian. However, the firmware interface requires it
* to be read a word (two bytes) at a time.
*


--
Jiri Kosina
SUSE Labs